@@ -1,9 +1,10 @@
+from __future__ import print_function
 # make plots of etopo bathymetry/topography data on
 # various map projections, drawing coastlines, state and
 # country boundaries, filling continents and drawing
 # parallels/meridians
 
-from mpl_toolkits.basemap import Basemap, shiftgrid
+from mpl_toolkits.basemap import Basemap, shiftgrid, cm
 import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.colors as colors
@@ -18,8 +19,8 @@ latsin = np.loadtxt('etopo20lats.gz')
 topoin,lons = shiftgrid(180.,topodatin,lonsin,start=False)
 lats = latsin
 
-print 'min/max etopo20 data:'
-print topoin.min(),topoin.max()
+print('min/max etopo20 data:')
+print(topoin.min(),topoin.max())
 
 # create new figure
 fig=plt.figure()
@@ -44,8 +45,8 @@ delon = 60.
 meridians = np.arange(-180,180,delon)
 m.drawmeridians(meridians,labels=[1,0,0,1])
 plt.title('Cylindrical Equidistant')
-print 'plotting Cylindrical Equidistant example ...'
-print m.proj4string
+print('plotting Cylindrical Equidistant example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -64,8 +65,8 @@ m.drawparallels(circles,labels=[1,1,1,1])
 # draw meridians
 m.drawmeridians(meridians,labels=[1,1,1,1])
 plt.title('Miller Cylindrical',y=1.1)
-print 'plotting Miller Cylindrical example ...'
-print m.proj4string
+print('plotting Miller Cylindrical example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -84,8 +85,8 @@ m.drawparallels(circles,labels=[1,1,1,1])
 # draw meridians
 m.drawmeridians(meridians,labels=[1,1,1,1])
 plt.title('Gall Stereographic Cylindrical',y=1.1)
-print 'plotting Gall Stereographic Cylindrical example ...'
-print m.proj4string
+print('plotting Gall Stereographic Cylindrical example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -108,8 +109,8 @@ m.drawparallels(circles,labels=[1,1,1,1])
 # draw meridians
 m.drawmeridians(meridians,labels=[1,1,1,1])
 plt.title('Mercator',y=1.1)
-print 'plotting Mercator example ...'
-print m.proj4string
+print('plotting Mercator example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -134,8 +135,8 @@ delon = 2.
 meridians = np.arange(-10,10,delon)
 m.drawmeridians(meridians,labels=[1,0,0,1],fontsize=10)
 plt.title('Cassini-Soldner Projection')
-print 'plotting Cassini-Soldner example ...'
-print m.proj4string
+print('plotting Cassini-Soldner example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -161,34 +162,34 @@ delon = 20.
 meridians = np.arange(-180,180,delon)
 m.drawmeridians(meridians,labels=[1,0,0,1],fontsize=10)
 plt.title('Gnomonic Projection')
-print 'plotting Gnomonic example ...'
-print m.proj4string
+print('plotting Gnomonic example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
 # setup transverse mercator basemap.
-m = Basemap(width=2*6370997,height=3.1*6370997,\
-            resolution='c',area_thresh=10000.,projection='cass',\
-            lat_0=0.,lon_0=-90.)
+m = Basemap(llcrnrlon=-6,llcrnrlat=49,urcrnrlon=4,urcrnrlat=59,\
+            resolution='l',area_thresh=1000.,projection='tmerc',\
+            lat_0=54.,lon_0=-2.)
 fig.add_axes([0.125,0.2,0.6,0.6])
 # transform to nx x ny regularly spaced native projection grid
-nx = int((m.xmax-m.xmin)/40000.)+1; ny = int((m.ymax-m.ymin)/40000.)+1
+nx = int((m.xmax-m.xmin)/20000.)+1; ny = int((m.ymax-m.ymin)/20000.)+1
 topodat = m.transform_scalar(topoin,lons,lats,nx,ny)
 # plot image over map.
 im = m.imshow(topodat,plt.cm.jet)
 m.colorbar() # draw colorbar
 m.drawcoastlines()
 # draw parallels
-delat = 20.
-circles = np.arange(-80.,100.,delat)
-m.drawparallels(circles,labels=[1,0,0,0],fontsize=10)
+delat = 2.
+circles = np.arange(40.,70.,delat)
+m.drawparallels(circles,labels=[1,0,0,1],fontsize=10)
 # draw meridians
-delon = 20.
-meridians = np.arange(-180,180,delon)
-m.drawmeridians(meridians,labels=[1,0,0,0],fontsize=10)
+delon = 2.
+meridians = np.arange(-10,10,delon)
+m.drawmeridians(meridians,labels=[1,0,0,1],fontsize=10)
 plt.title('Transverse Mercator Projection')
-print 'plotting Transverse Mercator example ...'
-print m.proj4string
+print('plotting Transverse Mercator example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -210,8 +211,8 @@ m.drawparallels(np.arange(-80,81,20),labels=[1,0,0,0],fontsize=10)
 # draw meridians
 m.drawmeridians(np.arange(-180,181,30),labels=[0,0,0,1],fontsize=10)
 plt.title('Oblique Mercator Projection')
-print 'plotting Oblique Mercator example ...'
-print m.proj4string
+print('plotting Oblique Mercator example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -237,8 +238,8 @@ delon = 20.
 meridians = np.arange(-180,180,delon)
 m.drawmeridians(meridians,labels=[1,0,0,1],fontsize=10)
 plt.title('Polyconic Projection')
-print 'plotting Polyconic example ...'
-print m.proj4string
+print('plotting Polyconic example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -265,8 +266,8 @@ delon = 5.
 meridians = np.arange(-100,-60,delon)
 m.drawmeridians(meridians,labels=[0,0,0,1])
 plt.title('Equidistant Conic')
-print 'plotting Equidistant Conic example ...'
-print m.proj4string
+print('plotting Equidistant Conic example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -294,8 +295,8 @@ delon = 30.
 meridians = np.arange(10.,360.,delon)
 m.drawmeridians(meridians,labels=[1,1,0,1])
 plt.title('Lambert Conformal Conic')
-print 'plotting Lambert Conformal example ...'
-print m.proj4string
+print('plotting Lambert Conformal example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -323,8 +324,8 @@ delon = 30.
 meridians = np.arange(10.,360.,delon)
 m.drawmeridians(meridians,labels=[1,1,1,1])
 plt.title('Albers Equal Area Conic',y=1.075)
-print 'plotting Albers Equal Area example ...'
-print m.proj4string
+print('plotting Albers Equal Area example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -349,9 +350,31 @@ m.drawcountries()
 m.drawparallels(circles)
 # draw meridians
 m.drawmeridians(meridians,labels=[1,1,1,1])
-plt.title('Polar Stereographic',y=1.075)
-print 'plotting Stereographic example ...'
-print m.proj4string
+plt.title('Square Polar Stereographic',y=1.075)
+print('plotting Square Stereographic example ...')
+print(m.proj4string)
+
+# create new figure
+fig=plt.figure()
+m = Basemap(lon_0=75.,boundinglat=-20,
+            resolution='c',area_thresh=10000.,projection='spstere',round=True)
+# transform to nx x ny regularly spaced native projection grid
+nx = int((m.xmax-m.xmin)/40000.)+1; ny = int((m.ymax-m.ymin)/40000.)+1
+topodat = m.transform_scalar(topoin,lons,lats,nx,ny)
+ax = fig.add_axes([0.1,0.1,0.7,0.7])
+# plot image over map.
+im = m.imshow(topodat,plt.cm.jet)
+m.colorbar(pad='12%') # draw colorbar
+m.drawcoastlines()
+m.drawcountries()
+#m.fillcontinents()
+# draw parallels.
+m.drawparallels(circles)
+# draw meridians
+m.drawmeridians(meridians,labels=[1,1,1,1])
+plt.title('Round Polar Stereographic',y=1.075)
+print('plotting Round Stereographic example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -377,9 +400,32 @@ m.drawstates()
 m.drawparallels(circles)
 # draw meridians
 m.drawmeridians(meridians,labels=[1,1,1,1])
-plt.title('Lambert Azimuthal Equal Area',y=1.075)
-print 'plotting Lambert Azimuthal example ...'
-print m.proj4string
+plt.title('Square Lambert Azimuthal Equal Area',y=1.075)
+print('plotting Square Lambert Azimuthal example ...')
+print(m.proj4string)
+
+# create new figure
+fig=plt.figure()
+m = Basemap(lon_0=-105,boundinglat=20.,
+            resolution='c',area_thresh=10000.,projection='nplaea',round=True)
+# transform to nx x ny regularly spaced native projection grid
+nx = int((m.xmax-m.xmin)/40000.)+1; ny = int((m.ymax-m.ymin)/40000.)+1
+topodat = m.transform_scalar(topoin,lons,lats,nx,ny)
+ax = fig.add_axes([0.1,0.1,0.7,0.7])
+# plot image over map.
+im = m.imshow(topodat,plt.cm.jet)
+m.colorbar(pad='12%') # draw colorbar
+m.drawcoastlines()
+m.drawcountries()
+m.drawstates()
+#m.fillcontinents()
+# draw parallels.
+m.drawparallels(circles)
+# draw meridians
+m.drawmeridians(meridians,labels=[1,1,1,1])
+plt.title('Round Lambert Azimuthal Equal Area',y=1.075)
+print('plotting Round Lambert Azimuthal example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -406,8 +452,8 @@ m.drawparallels(circles)
 # draw meridians
 m.drawmeridians(meridians,labels=[1,1,1,1])
 plt.title('Azimuthal Equidistant',y=1.075)
-print 'plotting Azimuthal Equidistant example ...'
-print m.proj4string
+print('plotting Azimuthal Equidistant example ...')
+print(m.proj4string)
 
 # projections with elliptical boundaries (orthographic, sinusoidal,
 # mollweide and robinson)
@@ -443,10 +489,9 @@ m.drawparallels(parallels)
 meridians = np.arange(0.,360.,20.)
 m.drawmeridians(meridians)
 # draw boundary around map region.
-m.drawmapboundary()
 plt.title('Orthographic')
-print 'plotting Orthographic example ...'
-print m.proj4string
+print('plotting Orthographic example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -480,10 +525,9 @@ m.drawparallels(parallels)
 meridians = np.arange(0.,360.,20.)
 m.drawmeridians(meridians)
 # draw boundary around map region.
-m.drawmapboundary()
 plt.title('Geostationary')
-print 'plotting Geostationary example ...'
-print m.proj4string
+print('plotting Geostationary example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -503,10 +547,9 @@ m.drawparallels(parallels,labels=[1,0,0,0])
 meridians = np.arange(0.,360.,30.)
 m.drawmeridians(meridians)
 # draw boundary around map region.
-m.drawmapboundary()
 plt.title('Sinusoidal')
-print 'plotting Sinusoidal example ...'
-print m.proj4string
+print('plotting Sinusoidal example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -526,10 +569,9 @@ m.drawparallels(parallels,labels=[1,0,0,0])
 meridians = np.arange(0.,360.,30.)
 m.drawmeridians(meridians)
 # draw boundary around map region.
-m.drawmapboundary()
 plt.title('Mollweide')
-print 'plotting Mollweide example ...'
-print m.proj4string
+print('plotting Mollweide example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -549,10 +591,9 @@ m.drawparallels(parallels,labels=[1,0,0,0])
 meridians = np.arange(0.,360.,30.)
 m.drawmeridians(meridians)
 # draw boundary around map region.
-m.drawmapboundary()
 plt.title('Hammer')
-print 'plotting Hammer example ...'
-print m.proj4string
+print('plotting Hammer example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -563,7 +604,7 @@ ax = fig.add_axes([0.1,0.1,0.7,0.7])
 # plot image over map with pcolormesh.
 x,y = m(*np.meshgrid(lonsin,latsin))
 p = m.pcolormesh(x,y,topodatin,shading='flat')
-m.colorbar(location='bottom') # draw colorbar
+m.colorbar(location='bottom',pad='10%') # draw colorbar
 # draw coastlines and political boundaries.
 m.drawcoastlines()
 # draw parallels and meridians
@@ -572,10 +613,53 @@ m.drawparallels(parallels,labels=[1,0,0,0])
 meridians = np.arange(0.,360.,60.)
 m.drawmeridians(meridians,labels=[0,0,0,1])
 # draw boundary around map region.
-m.drawmapboundary()
 plt.title('Robinson')
-print 'plotting Robinson example ...'
-print m.proj4string
+print('plotting Robinson example ...')
+print(m.proj4string)
+
+# create new figure
+fig=plt.figure()
+# setup of basemap ('kav7' = Kavrayskiy VII projection)
+m = Basemap(projection='kav7',
+            resolution='c',area_thresh=10000.,lon_0=0.5*(lonsin[0]+lonsin[-1]))
+ax = fig.add_axes([0.1,0.1,0.7,0.7])
+# plot image over map with pcolormesh.
+x,y = m(*np.meshgrid(lonsin,latsin))
+p = m.pcolormesh(x,y,topodatin,shading='flat')
+m.colorbar(location='bottom',pad='10%') # draw colorbar
+# draw coastlines and political boundaries.
+m.drawcoastlines()
+# draw parallels and meridians
+parallels = np.arange(-60.,90,30.)
+m.drawparallels(parallels,labels=[1,0,0,0])
+meridians = np.arange(0.,360.,60.)
+m.drawmeridians(meridians,labels=[0,0,0,1])
+# draw boundary around map region.
+plt.title('Kavrayskiy VII')
+print('plotting Kavrayskiy VII example ...')
+print(m.proj4string)
+
+# create new figure
+fig=plt.figure()
+# setup of basemap ('eck4' = Eckert IV projection)
+m = Basemap(projection='eck4',
+            resolution='c',area_thresh=10000.,lon_0=0.5*(lonsin[0]+lonsin[-1]))
+ax = fig.add_axes([0.1,0.1,0.7,0.7])
+# plot image over map with pcolormesh.
+x,y = m(*np.meshgrid(lonsin,latsin))
+p = m.pcolormesh(x,y,topodatin,shading='flat')
+m.colorbar(location='bottom',pad='10%') # draw colorbar
+# draw coastlines and political boundaries.
+m.drawcoastlines()
+# draw parallels and meridians
+parallels = np.arange(-60.,90,30.)
+m.drawparallels(parallels,labels=[1,0,0,0])
+meridians = np.arange(0.,360.,60.)
+m.drawmeridians(meridians,labels=[0,0,0,1])
+# draw boundary around map region.
+plt.title('Eckert IV')
+print('plotting Eckert IV example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -595,10 +679,9 @@ m.drawparallels(parallels,labels=[1,0,0,0])
 meridians = np.arange(0.,360.,60.)
 m.drawmeridians(meridians,labels=[0,0,0,1],fontsize=8)
 # draw boundary around map region.
-m.drawmapboundary()
 plt.title('McBryde-Thomas Flat Polar Quartic')
-print 'plotting McBryde-Thomas Flat Polar Quartic example ...'
-print m.proj4string
+print('plotting McBryde-Thomas Flat Polar Quartic example ...')
+print(m.proj4string)
 
 # create new figure
 fig=plt.figure()
@@ -617,12 +700,11 @@ m.drawparallels(parallels)
 meridians = np.arange(0.,360.,60.)
 m.drawmeridians(meridians)
 # draw boundary around map region.
-m.drawmapboundary()
 # add a title.
 plt.title('van der Grinten')
-print 'plotting van der Grinten example ...'
-print m.proj4string
+print('plotting van der Grinten example ...')
+print(m.proj4string)
 
 plt.show()
 
-print 'done'
+print('done')
