@@ -8,7 +8,7 @@ _dg2rad = math.radians(1.)
 _rad2dg = math.degrees(1.)
 
 _cylproj = ['cyl','merc','mill','gall']
-_pseudocyl = ['moll','robin','sinu','mbtfpq','vandg','hammer']
+_pseudocyl = ['moll','kav7','eck4','robin','sinu','mbtfpq','vandg','hammer']
 
 _upper_right_out_of_bounds = (
     'the upper right corner of the plot is not in the map projection region')
@@ -185,6 +185,9 @@ class Proj(object):
             urcrnrx,xtmp = self(projparams['lon_0']+180.,0)
             llcrnrx = -urcrnrx
             llcrnry = -urcrnry
+            if self.ellipsoid and self.projection in ['kav7','eck4','mbtfpq']:
+                msg = "this projection can only be drawn for a perfect sphere"
+                raise ValueError(msg)
         else:
             self._proj4 = pyproj.Proj(projparams)
             llcrnrx, llcrnry = self(llcrnrlon,llcrnrlat)
